@@ -3,11 +3,9 @@ import cv2, requests
 from PIL import Image, ImageDraw, ImageFont
 
 # Let's Download the background image at
-# https://raw.githubusercontent.com/tttienthinh/colorGenerator/main/test/test4-bg.jpg
-"""
-image = requests.get("https://raw.githubusercontent.com/tttienthinh/colorGenerator/main/test/test4-bg.jpg")
+url = "https://raw.githubusercontent.com/tttienthinh/colorGenerator/main/test/test4-bg.jpg"
+image = requests.get(url)
 open("test4-bg.jpg", "wb").write(image.content)
-"""
 
 # Pick two colors from the image
 img = cv2.imread("test4-bg.jpg")
